@@ -88,13 +88,16 @@ class Domain(BaseAPI):
         domain = self.get_data("domains", type=POST, params=data)
         return domain
 
-    def get_records(self):
+    def get_records(self, params=None):
         """
             Returns a list of Record objects
         """
+        if params is None:
+            params = {}
+        
         # URL https://api.digitalocean.com/v2/domains/[NAME]/records/
         records = []
-        data = self.get_data("domains/%s/records/" % self.name, type=GET)
+        data = self.get_data("domains/%s/records/" % self.name, type=GET, params=params)
 
         for record_data in data['domain_records']:
 
