@@ -1,4 +1,9 @@
 # -*- coding: utf-8 -*-
+try:
+    from urlparse import urlparse, parse_qs
+except:
+    from urllib.parse import urlparse, parse_qs
+
 from .baseapi import BaseAPI
 from .Droplet import Droplet
 from .Region import Region
@@ -10,6 +15,7 @@ from .Action import Action
 from .Account import Account
 from .FloatingIP import FloatingIP
 
+
 class Manager(BaseAPI):
     def __init__(self, *args, **kwargs):
         super(Manager, self).__init__(*args, **kwargs)
@@ -41,7 +47,8 @@ class Manager(BaseAPI):
             than one page)
         """
         try:
-            pages = data['links']['pages']['last'].split('=')[-1]
+            lastpage_url = data['links']['pages']['last']
+            pages = parse_qs(urlparse(lastpage_url).query)['page'][0]
             key, values = data.popitem()
             for page in range(2, int(pages) + 1):
                 params.update({'page': page})
@@ -92,7 +99,22 @@ class Manager(BaseAPI):
                     droplet.ip_address = net['ip_address']
             if droplet.networks['v6']:
                 droplet.ip_v6_address = droplet.networks['v6'][0]['ip_address']
+
+            if "backups" in droplet.features:
+                droplet.backups = True
+            else:
+                droplet.backups = False
+            if "ipv6" in droplet.features:
+                droplet.ipv6 = True
+            else:
+                droplet.ipv6 = False
+            if "private_networking" in droplet.features:
+                droplet.private_networking = True
+            else:
+                droplet.private_networking = False
+
             droplets.append(droplet)
+
         return droplets
 
     def get_droplet(self, droplet_id):
